'use strict';

var _ = require('lodash');
var classNames = require('classnames');
var React = require('react');

var ConfigItemTitle = require('./ConfigItemTitle');
// var ConfigItemDescription = require('./ConfigItemDescription');
// var ConfigGroupDescription = require('./ConfigGroupDescription');
var ConfigItemHelpText = require('./ConfigItemHelpText');
var ConfigTestWidget = require('./ConfigTestWidget');
var ConfigService = require('../services/ConfigService');

var fields = {
  'select': React.createFactory(require('./ConfigFieldSelect')),
  'textarea': React.createFactory(require('./ConfigFieldTextArea')),
  'text': React.createFactory(require('./ConfigFieldText')),
  'password': React.createFactory(require('./ConfigFieldPassword')),
  'file': React.createFactory(require('./ConfigFieldFile')),
  'bool': React.createFactory(require('./ConfigFieldCheckbox')),
  'select_one': React.createFactory(require('./ConfigFieldSelectOne')),
  'select_many': React.createFactory(require('./ConfigFieldSelectMany')),
  'label': React.createFactory(require('./ConfigFieldLabel')),
  'heading': React.createFactory(require('./ConfigFieldHeading'))
};

var ConfigItem = React.createClass({
  displayName: 'ConfigItem',

  handleItemChange: function handleItemChange(name, value, data) {
    if (this.props.handleChange) {
      this.props.handleChange(name, value, data);
    }
  },

  renderGroup: function render(group) {
    if (!ConfigService.isVisible(this.props.groups, group)) {
      return React.createElement('div', { id: 'config-item-' + group.name });
    }

    var items = _.map(group.items, (function (item) {
      if (item.type === 'group') {
        return this.renderGroup(item);
      }
      return React.createElement(ConfigItem, {
        key: item.name,
        groups: this.props.groups,
        item: item,
        enabled: ConfigService.isEnabled(this.props.groups, item),
        visible: ConfigService.isVisible(this.props.groups, item),
        handleChange: this.handleItemChange,
        onTestProc: this.props.onTestProc });
    }).bind(this));

    return React.createElement(
      'div',
      { id: 'config-item-' + group.name },
      items
    );
  },

  render: function render() {
    if (this.props.item.type === 'group') {
      // NOTE: This type is for internal use only.  It is unsupported in app config screen.
      return this.renderGroup(this.props.item);
    }

    var title = null;
    var description = null;
    var field = null;
    var testWidget = null;

    function getItemTestWidget(groups, item, onTestProc) {
      var testProcData = _.get(item, 'test_proc');
      var testProcDataWhen = _.get(testProcData, 'when');
      var testProcWhen = testProcDataWhen === '' ? true : ConfigService.parseBool(testProcDataWhen);
      var showTestWidget = testProcWhen && (_.get(testProcData, 'command') || _.get(testProcData, 'custom_command.id'));
      if (showTestWidget) {
        // Item test proc will always have itself as the only argument
        var argFields = [item.name];
        return React.createElement(
          'div',
          { style: { marginTop: '10px' } },
          React.createElement(ConfigTestWidget, {
            boundItem: item.name,
            groups: groups,
            timeout: item.test_proc.timeout,
            argFields: argFields,
            displayName: item.test_proc.display_name,
            onTestProc: onTestProc })
        );
      }
      return null;
    }

    if (this.props.item.type === 'label') {
      title = React.createElement(ConfigItemTitle, { title: this.props.item.title });
      /*
      if (_.get(this.props.item, 'description')) {
        description = (
          <ConfigItemDescription text={this.props.item.description} />
        );
      }
      */
    } else if (this.props.item.type === 'heading') {
        title = React.createElement(
          'div',
          { className: 'config-group clearfix' },
          React.createElement(
            'h3',
            { className: 'group-title' },
            this.props.item.title
          )
        );
        /*
        if (_.get(this.props.item, 'description')) {
          description = (
            <div className="row">
              <ConfigGroupDescription text={this.props.item.description} />
            </div>
          );
        }
        */
      } else {
          title = React.createElement(ConfigItemTitle, {
            title: this.props.item.title,
            required: this.props.item.required === true,
            recommended: this.props.item.recommended === true });
          /*
          if (_.get(this.props.item, 'description')) {
            description = (
              <ConfigItemDescription text={this.props.item.description} />
            );
          }
          */
          testWidget = getItemTestWidget(this.props.groups, this.props.item, this.props.onTestProc);
        }

    var props = {
      title: title,
      name: this.props.item.name,
      value: this.props.item.value,
      multi_value: this.props.item.multi_value,
      'default': this.props.item['default'],
      props: this.props.item.props,
      enabled: this.props.enabled,
      readOnly: this.props.item.readonly === true || this.props.item.locked === true,
      multiple: this.props.item.multiple === true,
      items: this.props.item.items || [],
      handleChange: this.handleItemChange
    };

    if (this.props.item.type in fields) {
      field = fields[this.props.item.type](props);
    } else if (this.props.item.type) {
      // unknown field type
      return null;
    }

    var helpText = _.get(this.props.item, 'help_text') || null;
    if (helpText) {
      helpText = React.createElement(ConfigItemHelpText, { text: this.props.item.help_text });
    }

    var classes = classNames('form-group col-xs-12', {
      'col-sm-6': this.props.item.affix === 'left' || this.props.item.affix === 'right',
      'hidden': !this.props.visible
    });

    return React.createElement(
      'div',
      {
        id: 'config-item-' + this.props.item.name,
        className: classes },
      field,
      description,
      helpText,
      testWidget
    );
  }
});

module.exports = ConfigItem;
//# sourceMappingURL=ConfigItem.js.map
